#
#    Set up some global variables for file names and locations
#    for running the gated config file generator and test program.
#

#
#    THE FOLLOWING VARIABLES ARE SYSTEM- AND USER-DEPENDENT.
#
#    gated_work_dir       Directory where the gated.conf, expected.txt,
#                         and gated (or link to) are located.
#
#    gated_mainlog_dir    Tells gated where to write the log file.
#                         Used by config file generator to set file name
#                         and by test program as reference.
#
#    gated_locallog_dir   Directory used by test program to save copies of
#                         the current gated log file and routing table.
#
#    gated_test_dir       Directory which contains the individual test
#                         subdirectories.
#
#    gated_script_dir     Directory containing scripts needed for running
#                         the automated tester and the gated config file
#                         generator.
#
#    gated_template_dir   Directory containing templates needed for running
#			  the gated config file generator.
#
#    gated_sync_dir       Directory for coordinating node synchronization
#                         (having all nodes run the same test at the same time).
#
#    gated_qos_dir        Directory where QOS file is located (used by
#                         compare script).
#
#    gated_perl_cmd       Perl executable (directory and file name).
#

setenv lusr_dir              /lusr/jeff/gated/next_gen

if ( `arch` == "i386" ) then
   setenv home_dir           /usr/home/jeff/gated/next_gen
else
   setenv home_dir           /home/jeff/gated/next_gen
endif

setenv gated_work_dir        $home_dir/working
setenv gated_mainlog_dir     $home_dir/log
setenv gated_locallog_dir    $home_dir/log
setenv gated_test_dir        $lusr_dir/tests
setenv gated_script_dir      $lusr_dir/scripts
setenv gated_template_dir    $lusr_dir/templates
setenv gated_sync_dir        $lusr_dir/sync
setenv gated_qos_dir         /var/tmp

if ( `arch` == "i386" ) then
   setenv gated_perl_cmd        /usr/bin/perl
else
   setenv gated_perl_cmd        /usr/local/bin/perl
endif

#
#    SYSTEM INDEPENDENT VARS
#

#  Name of the gated log file
setenv gated_log_file_name gatedlog.idrp

#  Location of machine map for config file generator
setenv gated_machine_map $gated_script_dir/machines.map

#  Location of route sets for config file generator
setenv gated_rte_set_file $gated_script_dir/route_sets.txt

#  Location of template for config file generator
setenv gated_template_file $gated_template_dir/main_template.tpl

#  Name of the config file gated is to use
setenv gated_config_file $gated_work_dir/gated.conf

#  Name of the expected results file
setenv gated_results_file $gated_work_dir/expected.txt

#  Name of the patterns file used by compare script
setenv gated_cmp_pat_file $gated_script_dir/cmp_patterns.txt

#  Name of the script to use to compare routing table
#  with expected results
setenv gated_cmp_script "$gated_perl_cmd $gated_script_dir/cmp_results.perl"

#  Name of the QOS file (used in comparing expected results)
setenv gated_qos_file $gated_qos_dir/qos_kernel.log

#  Default waiting time before comparing routing table vs. expected
setenv testg_def_wait_time 30
